SystemOrganization addCategory: #'ToolsTest-Base'!
SystemOrganization addCategory: #'ToolsTest-Debugger'!
SystemOrganization addCategory: #'ToolsTest-Inspector'!
SystemOrganization addCategory: #'ToolsTest-MessageTally'!
SystemOrganization addCategory: #'ToolsTest-PointerFinder'!

TestCase subclass: #DebuggerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolsTest-Debugger'!

!DebuggerTest methodsFor: 'testing' stamp: 'IgorStasenko 4/26/2011 16:55'!
testBasic
	| context process debugger indice|
	context := [ 20 factorial ] asContext.
	indice := 1.

	process := Process 
		forContext: context
		priority: Processor userInterruptPriority.

	debugger := Smalltalk tools debugger new
						process: process
						controller: nil
						context: context.
	debugger expandStack.
	debugger toggleContextStackIndex: 1.
	"The index of the message list is 1 "
	self assert: debugger messageListIndex = 1.
"	debugger openFullNoSuspendLabel: 'hello'."
"	debugger down."
"	debugger up."
	self assert: debugger messageListIndex = 1.
"	debugger toggleContextStackIndex: 1."
	self assert: debugger selectedContext printString = '[20 factorial] in DebuggerTest>>testBasic'.
"	self assert: debugger selectedMessage = self."	
"	debugger openFullNoSuspendLabel: 'Text'."
	debugger send.
	debugger send.
	self assert: debugger contents = (Integer>>#factorial) getSourceFromFile.
	self assert: debugger selectedContext printString =  'SmallInteger(Integer)>>factorial'.! !

TestCase subclass: #DynamicMessageImplementorTest
	instanceVariableNames: 'instVar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolsTest-Debugger'!

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 17:24'!
testAnShouldBeUsedAsPrefixWhenArgumentNameStartsWithVowel

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #m1: argument: #()) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'm1: anArray self shouldBeImplemented.' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 17:20'!
testBinaryMessage

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #+ argument: 1) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = '+ aSmallInteger self shouldBeImplemented.' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 16:48'!
testImplementingAMessageNamedAsVariableShouldGenerateGetter

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #instVar) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'instVar self shouldBeImplemented.	^ instVar' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 16:54'!
testImplementingAMessageNamedAsVariableWithOneParameterShouldGenerateSetter

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #instVar: argument: 1) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'instVar: aSmallInteger self shouldBeImplemented. instVar := aSmallInteger' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 16:57'!
testImplementingKeywordMessageWithOneArgumentNamedDifferentToAllInstanceVariablesShouldNotGenerateSetter

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #m1: argument: 1) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'm1: aSmallInteger self shouldBeImplemented.' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 16:55'!
testImplementingUnaryMessageNamedDifferentToAllInstanceVariablesShouldNotGenerateGetter

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #m1) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'm1 self shouldBeImplemented.' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 17:23'!
testKeywordMessageWithDiferentArgumentClass

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #m1:m2:m3: arguments: #(1 $a 'string')) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'm1: aSmallInteger m2: aCharacter m3: aByteString self shouldBeImplemented.' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/12/2010 17:22'!
testKeywordMessageWithSameArgumentClassShouldGenerateDifferentArgumentNames

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #m1:m2:m3: arguments: #(1 2 3)) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'm1: aSmallInteger m2: aSmallInteger2 m3: aSmallInteger3 self shouldBeImplemented.' withSeparatorsCompacted! !

!DynamicMessageImplementorTest methodsFor: 'testing' stamp: 'HernanWilkinson 10/13/2010 10:54'!
testMetaclassNameShouldBeUsedWhenArgumentIsAClass

	| messageImplementor sourceCode |		
	
	messageImplementor := DynamicMessageImplementor for: (Message selector: #m1: argument: Array) in: self class.	
	sourceCode := messageImplementor value.	
	self assert: sourceCode withSeparatorsCompacted = 'm1: anArrayClass self shouldBeImplemented.' withSeparatorsCompacted! !

TestCase subclass: #MessageTallyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolsTest-MessageTally'!

!MessageTallyTest methodsFor: 'tallying' stamp: 'Alexandre Bergel 3/5/2010 17:53'!
testClosedTally

	| tally |
	tally := MessageTally
				tallySendsTo: nil 
				inBlock:  [ 3.14159 printString ] 
				showTree: true 
				closeAfter: true 
				openResultWindow: false.
				
	"The tally is closed, therefore nothing may be accessed"
	self assert: (tally receivers isNil)! !

!MessageTallyTest methodsFor: 'basic' stamp: 'Alexandre Bergel 3/4/2010 18:44'!
testInstantiation

	| messageTally |
	messageTally := MessageTally new.
	self assert: (messageTally time = 0).
	self assert: (messageTally tally = 0)! !

!MessageTallyTest methodsFor: 'sampling' stamp: 'Alexandre Bergel 3/15/2010 21:03'!
testSampling1

	| tally |
	tally := MessageTally
				spyOn: [ 1000  timesRepeat: [ 3.14159 printString  ] ]  
				reportOtherProcesses: false 
				cutoff: 1 
				openResultWindow: false
				closeAfter: false.

	"No process is accessible from the tally, the reason is that using the sampling method execute the block in the current process"
	self assert: (tally process isNil).

! !

!MessageTallyTest methodsFor: 'tallying' stamp: 'AlexandreBergel 12/22/2010 10:41'!
testTallySends
	"
	self debug: #testTallySends
	"
	
	| tally thisMethod activeProcess allProcesses numberOfProcesses processUsedByTally tallyForPrintString tallyForPrintStringBase tallyForSmallIntegerStar |
	allProcesses := Process allInstances.
	numberOfProcesses := allProcesses size.

	tally := MessageTally 
				tallySendsTo: nil 
				inBlock:  [ 3.14159 printString ] 
				showTree: true 
				closeAfter: false 
				openResultWindow: false.
	
	"tally is for this test method"
	thisMethod := self class >> #testTallySends.
	self assert: (tally hash = thisMethod hash).
	self assert: (tally method == thisMethod).
	self assert: (tally theClass == self class).


	processUsedByTally := tally process.
	self deny: (allProcesses includes: processUsedByTally).

	"Below is specialized for the execution ' 3.14159 printString '. Any method change in the execution flow of printString will turn this test to yellow"
	self assert: (tally tally >= 50).
	"The tally is not close, therefore the tree may be crawled over"
	self assert: (tally receivers isArray).
	self assert: (tally receivers size = 2).
	
	"--------"
	tallyForPrintString := tally receivers second.
	"Since 3.14159 is a float"
	self assert: (tallyForPrintString theClass == Float).
	"the executed method is Number>>printString"
	self assert: (tallyForPrintString method == ( Number>>#printString)).
	self assert: (tallyForPrintString tally >= 50).

	"--------"
	tallyForPrintStringBase := tallyForPrintString receivers first.
	"The receiver is still a Float"
	self assert: (tallyForPrintString theClass == Float).
	"the executed method is Number>>printStringBase: this time"
	self assert: (tallyForPrintStringBase method == ( Number>>#printStringBase:)).
	self assert: (tallyForPrintStringBase tally >= 50).
	
	"The method printStringBase: calls two methods:
	   SequenceableCollection class >> streamContents: and Float >> printOn:base:"
	
	self assert: (tallyForPrintStringBase receivers size = 2).
	
	"streamContents: is been tallied 13 times and printOn:base: 59 times"
	self assert: (tallyForPrintStringBase receivers size = 2).	
	self assert: (tallyForPrintStringBase receivers first tally) = 13.	
	self assert: (tallyForPrintStringBase receivers second tally) >= 50.	

	"--------"
	tallyForSmallIntegerStar := tallyForPrintStringBase receivers second receivers second receivers third.
	self assert: (tallyForSmallIntegerStar theClass inheritsFrom: Integer).

	"We close to explicitely release reference of the process, the class and methods"
	tally close.
	
	
! !

!MessageTallyTest methodsFor: 'tallying' stamp: 'Alexandre Bergel 3/5/2010 17:29'!
testTallyShouldNotContainsAReturn

	"The block passed to MessageTally should not have a ^ "
	
	self should: [ MessageTally
					tallySendsTo: nil 
					inBlock:  [ ^ 3.14159 printString ] 
					showTree: true 
					closeAfter: false 
					openResultWindow: false ] raise: Error.
	! !

TestCase subclass: #PointerFinderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolsTest-PointerFinder'!

!PointerFinderTest methodsFor: 'as yet unclassified' stamp: 'AndyKellens 6/11/2010 14:16'!
testBasic1

	| myObject myArray |
	myObject := Object new.
	myArray := {myObject . myObject}.
	self assert: (myObject pointersTo) asArray = {myArray}! !

!PointerFinderTest methodsFor: 'as yet unclassified' stamp: 'CamilloBruni 9/8/2011 14:37'!
testCycle

	| myObject myArray myArray2 pointingObjects |
	myObject := Object new.
	myArray := {myObject . myObject}.
	myArray2 := {myObject . myArray}.

	pointingObjects := (myObject pointersTo) asArray.
	self assert: pointingObjects size = 2.
	self assert: (pointingObjects includesAll: {myArray . myArray2}).
	
	"PointerFinder loops in presence of cycles"
"	myArray at: 1 put: myArray.
	pointingObjects := (PointerFinder pointersTo: myObject) asArray.
	self assert: pointingObjects = {myArray}.
"! !

!PointerFinderTest methodsFor: 'as yet unclassified' stamp: 'AndyKellens 6/11/2010 14:17'!
testNoPointingObject

	| myObject |
	myObject := Object new.
	self assert: (myObject pointersTo) isEmpty! !

TestCase subclass: #WeakSetInspectorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolsTest-Inspector'!

!WeakSetInspectorTest methodsFor: 'testing' stamp: 'IgorStasenko 4/26/2011 16:36'!
testSymbolTableM6812
	"this test is related to http://bugs.squeak.org/view.php?id=6812"
	
	| aWeakSet anInspector fieldSize |
	aWeakSet := (Symbol classPool at: #SymbolTable).
	anInspector := (Smalltalk tools inspectorClassOf: aWeakSet) inspect: aWeakSet.
	
	fieldSize := anInspector fieldList size.
	3 timesRepeat:
		[Smalltalk garbageCollect.
		self assert: fieldSize = anInspector fieldList size.]
	! !

TestCase subclass: #WorkspaceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolsTest-Base'!

!WorkspaceTest methodsFor: 'tests' stamp: 'AlexandreBergel 8/31/2011 17:58'!
testEmptyContent

	self assert: (Workspace new contents isEmpty)! !

!WorkspaceTest methodsFor: 'tests' stamp: 'AlexandreBergel 8/31/2011 17:56'!
testStyling

	| workspace |
	workspace := Workspace new.
	self assert: workspace stylingActive.
	
	workspace toggleStylingActive.
	self deny: workspace stylingActive.! !
